==> haskell-rio-prettyprint-0.1.0.0-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio-prettyprint
version: 0.1.0.0
id: rio-prettyprint-0.1.0.0-FbnY9hm6nZy14KOKgSllvZ
key: rio-prettyprint-0.1.0.0-FbnY9hm6nZy14KOKgSllvZ
license: BSD-3-Clause
copyright: 2018-2019 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Pretty-printing for RIO
category: Development
abi: 4eefa3df050e2262db4d6e0c1d29eb6c
exposed: True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended
hidden-modules: Paths_rio_prettyprint
import-dirs: /usr/lib/ghc-8.6.5/site-local/rio-prettyprint-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/rio-prettyprint-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/rio-prettyprint-0.1.0.0
hs-libraries: HSrio-prettyprint-0.1.0.0-FbnY9hm6nZy14KOKgSllvZ
depends:
    Cabal-2.4.0.1 aeson-1.4.6.0-6SSxkzo3COEI5l1mOYJmxL
    annotated-wl-pprint-0.7.0-DGkZQ2VEej1K9q8cmlJu7D
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj array-0.5.3.0
    base-4.12.0.0 colour-2.3.5-y0xjV3ONUd40VuBtReEvC mtl-2.2.2
    path-0.6.1-7qyDqq3ByCz1rjCGJoUF5M
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock
haddock-html: /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-prettyprint-0.1.0.0-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio-prettyprint
version: 0.1.0.0
id: rio-prettyprint-0.1.0.0-43S2VylLSUr9EDGk2EgdQ5
key: rio-prettyprint-0.1.0.0-43S2VylLSUr9EDGk2EgdQ5
license: BSD-3-Clause
copyright: 2018-2019 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Pretty-printing for RIO
category: Development
abi: 355c7db4db8634118d184ed1d4dad44b
exposed: True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended
hidden-modules: Paths_rio_prettyprint
import-dirs: /usr/lib/ghc-8.6.5/site-local/rio-prettyprint-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/rio-prettyprint-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/rio-prettyprint-0.1.0.0
hs-libraries: HSrio-prettyprint-0.1.0.0-43S2VylLSUr9EDGk2EgdQ5
depends:
    Cabal-2.4.0.1 aeson-1.4.6.0-Idz88Vw0zug9yYFt0rn4Ut
    annotated-wl-pprint-0.7.0-DGkZQ2VEej1K9q8cmlJu7D
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj array-0.5.3.0
    base-4.12.0.0 colour-2.3.5-y0xjV3ONUd40VuBtReEvC mtl-2.2.2
    path-0.6.1-F5GNQ955nvDAnwE5yQPzuX
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock
haddock-html: /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
